from mock import patch
from unittest import TestCase
from textwrap import dedent

from cidirector.git import GitRepo


class TestGitRepo(TestCase):

    def test_ls_remote(self):
        repo = GitRepo('git://github.com/foo/bar')
        with patch('subprocess.check_output', return_value='asdf') as co_mock:
            self.assertEqual('asdf', repo.ls_remote())
        co_mock.assert_called_once_with(
            ['git', 'ls-remote', '--heads', 'git://github.com/foo/bar'])

    def test_list_remote_branch_tips(self):
        repo = GitRepo('git://github.com/foo/bar')
        ls_remote_output = dedent("""\
            foo\trefs/heads/bar
            baz\trefs/heads/qux
        """)
        with patch.object(repo, 'ls_remote', return_value=ls_remote_output):
            output = list(repo.list_remote_branch_tips())
        self.assertEqual(output, [('bar', 'foo'), ('qux', 'baz')])
