__metaclass__ = type


import os
from shutil import rmtree
import subprocess
from tempfile import mkdtemp

from contextlib import contextmanager


ARCHIVE_BUCKET_URL = 's3://juju-qa-data'


@contextmanager
def temp_dir():
    dirname = mkdtemp()
    try:
        yield dirname
    finally:
        rmtree(dirname)


def archive_version_url(version):
    """Return the first part of the S3 URL used to store CI test results."""
    return '%s/juju-ci/products/version-%s' % (ARCHIVE_BUCKET_URL, version)


def run_s3cmd(params):
    """Invoke s3cmd with the right config file."""
    config_file = os.path.join(os.environ['HOME'], 'cloud-city/juju-qa.s3cfg')
    # "s3cmd put ..." is chatty: It will always print something like
    # "file 'foo' stored as 's3://juju-qa-data/...'". There seems not to
    # any command line option like "--quiet", so let's catch and drop
    # these message here.
    subprocess.check_output(['s3cmd', '-c', config_file] + params)
